/**
 * Copyright 2023 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
export type IconProvider = (iconId: string) => HTMLElement | URL | string;
export declare enum MaterialIconsStyle {
    FILLED = "filled",
    OUTLINED = "outlined",
    ROUNDED = "rounded",
    SHARP = "sharp",
    TWOTONE = "twotone"
}
/** The options for the MaterialIcons icon-provider. */
export type MaterialIconsOptions = {
    /** The material icon style to use. */
    style: MaterialIconsStyle;
    /**
     * Wether or not to automatically append the required stylesheet for the
     * icon-font.
     */
    appendFontStylesheet: boolean;
};
/**
 * Creates the MaterialIcons icon-provider. This will load the appropriate
 * material icons font if it's not detected and return the icon-provider
 * function that creates the dom-elements for the requested icon.
 *
 * @param options
 */
export declare function MaterialIcons(options?: Partial<MaterialIconsOptions>): IconProvider;
/**
 * Creates the PlaceIcons icon provider. This provider will use the SVG-icons
 * for the places API.
 */
export declare function PlaceIcons(): IconProvider;
